CGPCLI is Python libary that allows you to reach CGP servers and execute CLI commands from your Python code.

It consists of:
- **Commands**: contains all CLI command
- **Errors**: some errors with that you may handel
- **Connection**: methods to connect to CGP server
- **Parser**: includes methods to convert CGP objects to Python ones and vice versa

[CLI commands manual](http://www.communigate.ru/CommuniGatePro/CLI.html)